# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html
#

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

# -- Project information -----------------------------------------------------

project = u"dissector"
copyright = u"2026-03-07 07:00:18, Candace Makeda Moore"
author = u"Candace Makeda Moore"

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = "0.0.1"
# The full version, including alpha/beta/rc tags.
release = version

# -- General configuration ------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named "sphinx.ext.*") or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.coverage",
    "sphinx.ext.doctest",
    "sphinx.ext.intersphinx",
    "sphinx.ext.mathjax",
    "sphinx.ext.napoleon",
    "sphinx.ext.todo",
    "sphinx.ext.viewcode",
    "autoapi.extension",
    "myst_parser",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False

# -- Use autoapi.extension to run sphinx-apidoc -------

autoapi_dirs = ['../src/dissector']

# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
# html_theme_options = {}

# -- Options for Intersphinx

intersphinx_mapping = {'python': ('https://docs.python.org/3', None),
                       # Commonly used libraries, uncomment when used in package
                       # 'numpy': ('http://docs.scipy.org/doc/numpy/', None),
                       # 'scipy': ('http://docs.scipy.org/doc/scipy/reference/', None),
                       # 'scikit-learn': ('https://scikit-learn.org/stable/', None),
                       # 'matplotlib': ('https://matplotlib.org/stable/', None),
                       # 'pandas': ('http://pandas.pydata.org/docs/', None),
                       }



"""Documentation about the dissector module."""


# FIXME: put actual code here
def hello(name: str) -> str:
    """Say hello.

    Function docstring using Google docstring style.

    Args:
        name (str): Name to say hello to

    Returns:
        str: Hello message

    Raises:
        ValueError: If `name` is equal to `nobody`

    Example:
        This function can be called with `Jane Smith` as argument using

        >>> from dissector.my_module import hello
        >>> hello('Jane Smith')
        'Hello Jane Smith!'

    """
    if name == "nobody":
        msg = "Can not say hello to nobody"
        raise ValueError(msg)
    return f"Hello {name}!"



"""Documentation about dissector."""

import logging

logging.getLogger(__name__).addHandler(logging.NullHandler())

__author__ = "Candace Makeda Moore"
__email__ = "doctormakeda@gmail.com"
__version__ = "0.0.1"



"""Tests for the dissector.my_module module."""

import pytest
from dissector.my_module import hello


def test_hello():
    """Example using assert."""
    assert hello("nlesc") == "Hello nlesc!"


def test_hello_with_error():
    """Example of testing for raised errors."""
    with pytest.raises(ValueError) as excinfo:
        hello("nobody")
    assert "Can not say hello to nobody" in str(excinfo.value)


@pytest.fixture
def some_name():
    """Example fixture."""
    return "Jane Smith"


def test_hello_with_fixture(some_name: str):
    """Example using a fixture."""
    assert hello(some_name) == "Hello Jane Smith!"
